# itime: awesome convert for various time formats

## Installation

You can install itime package from [PyPI](https://pypi.org/project/itime/):

    pip install itime

The reader is supported on Python 2.7, as well as Python 3.4 and above.

## How to use

T.B.D.